@@ -45,7 +45,7 @@ def read_and_rename(file):
 def city_epsgcode(city):
     citydict = {'上海': 32651, '南京': 32650, '合肥': 32650, '重庆': 32648, '宁波': 32651, '杭州': 32651, '济南': 32650,
                 '沈阳': 32651, '广州': 32649, '北京': 32650, '昆明': 32648, '成都': 32648, '青岛': 32651, '长沙': 32649,
-                '徐州': 32650, '天津': 32650, '哈儿': 32652, '哈儿滨': 32652, '长春': 32651,'大连': 32651,}
+                '徐州': 32650, '天津': 32650, '哈尔滨': 32652, '哈尔': 32652, '长春': 32651,'大连': 32651,}
     if city in citydict:
         epsgcode = citydict[city]
     else:
